window.Gleam.initSearch([{"doc":"repeatedly","title":"repeatedly","content":"# repeatedly\n\nCall a function repeatedly with a delay between each call.\n\n[![Package Version](https://img.shields.io/hexpm/v/repeatedly)](https://hex.pm/packages/repeatedly)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/repeatedly/)\n\nWorks on both Erlang and JavaScript runtimes!\n\n```sh\ngleam add repeatedly\n```\n```gleam\nimport repeatedly\n\npub fn main() {\n  // Print every 500ms\n  let repeater = repeatedly.call(500, Nil, fn(_state, i) {\n    io.println(&quot;Call number &quot; &lt;&gt; int.to_string(i))\n  })\n\n  // And at some point later, stop it\n  repeatedly.stop(repeater)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/repeatedly&gt;.\n\n","url":"index.html"},{"doc":"repeatedly","title":"Repeater","content":"pub type Repeater(state)\n\n\nSynonyms:\nrepeatedly.Repeater\nrepeatedly Repeater","url":"repeatedly.html#Repeater"},{"doc":"repeatedly","title":"call","content":"pub fn call(\n  delay_ms: Int,\n  state: a,\n  function: fn(a, Int) -&gt; b,\n) -&gt; Repeater(a)\n Call a function every specified number of milliseconds, waiting the number\n of milliseconds before the first call.\n\nSynonyms:\nrepeatedly.call\nrepeatedly call","url":"repeatedly.html#call"},{"doc":"repeatedly","title":"set_function","content":"pub fn set_function(\n  repeater: Repeater(a),\n  function: fn(a, Int) -&gt; b,\n) -&gt; Nil\n Replace the function being called by a repeater.\n\n On Erlang if the repeater message queue is not empty then this message will\n handled after all other messages.\n\n On JavaScript there is no message queue so it will stop immediately, though\n not interrupt the function callback if currently being executed.\n\nSynonyms:\nrepeatedly.set_function\nrepeatedly set_function","url":"repeatedly.html#set_function"},{"doc":"repeatedly","title":"set_state","content":"pub fn set_state(repeater: Repeater(a), state: a) -&gt; Nil\n Set the repeater state.\n\n On Erlang if the repeater message queue is not empty then this message will\n handled after all other messages.\n\n On JavaScript there is no message queue so it will stop immediately, though\n not interrupt the function callback if currently being executed.\n\nSynonyms:\nrepeatedly.set_state\nrepeatedly set_state","url":"repeatedly.html#set_state"},{"doc":"repeatedly","title":"stop","content":"pub fn stop(repeater: Repeater(a)) -&gt; Nil\n Stop the repeater, preventing it from triggering again.\n\n On Erlang if the repeater message queue is not empty then this message will\n handled after all other messages.\n\n On JavaScript there is no message queue so it will stop immediately, though\n not interrupt the function callback if currently being executed.\n\nSynonyms:\nrepeatedly.stop\nrepeatedly stop","url":"repeatedly.html#stop"},{"doc":"repeatedly","title":"update_state","content":"pub fn update_state(\n  repeater: Repeater(a),\n  function: fn(a) -&gt; a,\n) -&gt; Nil\n Update the repeater state.\n\n On Erlang if the repeater message queue is not empty then this message will\n handled after all other messages.\n\n On JavaScript there is no message queue so it will stop immediately, though\n not interrupt the function callback if currently being executed.\n\nSynonyms:\nrepeatedly.update_state\nrepeatedly update_state","url":"repeatedly.html#update_state"},{"doc":"repeatedly","title":"repeatedly","content":"","url":"repeatedly.html"}]);